# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class FileShareServiceSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'share_name': 'str',
        'org_id': 'str',
        'local_path': 'str',
        'connector_id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'share_name': 'share_name',
        'org_id': 'org_id',
        'local_path': 'local_path',
        'connector_id': 'connector_id'
    }

    def __init__(self, name=None, share_name=None, org_id=None, local_path=None, connector_id=None, local_vars_configuration=None):  # noqa: E501
        """FileShareServiceSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._share_name = None
        self._org_id = None
        self._local_path = None
        self._connector_id = None
        self.discriminator = None

        self.name = name
        self.share_name = share_name
        self.org_id = org_id
        self.local_path = local_path
        self.connector_id = connector_id

    @property
    def name(self):
        """Gets the name of this FileShareServiceSpec.  # noqa: E501

        The name of the service. This uniquely identifies the service within the organisation.   # noqa: E501

        :return: The name of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileShareServiceSpec.

        The name of the service. This uniquely identifies the service within the organisation.   # noqa: E501

        :param name: The name of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def share_name(self):
        """Gets the share_name of this FileShareServiceSpec.  # noqa: E501

        The name of the share as exposed to the Internet. This will be used to build the URI used to mount the share. The share_name is unique among the file shares of the organisation.   # noqa: E501

        :return: The share_name of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._share_name

    @share_name.setter
    def share_name(self, share_name):
        """Sets the share_name of this FileShareServiceSpec.

        The name of the share as exposed to the Internet. This will be used to build the URI used to mount the share. The share_name is unique among the file shares of the organisation.   # noqa: E501

        :param share_name: The share_name of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and share_name is None:  # noqa: E501
            raise ValueError("Invalid value for `share_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                share_name is not None and len(share_name) > 1024):
            raise ValueError("Invalid value for `share_name`, length must be less than or equal to `1024`")  # noqa: E501

        self._share_name = share_name

    @property
    def org_id(self):
        """Gets the org_id of this FileShareServiceSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this FileShareServiceSpec.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def local_path(self):
        """Gets the local_path of this FileShareServiceSpec.  # noqa: E501

        The path to the directory to share on the local file system. This should point to a directory, not a file. Use a slash ('/', U+002F) to separate directories within the path.   # noqa: E501

        :return: The local_path of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._local_path

    @local_path.setter
    def local_path(self, local_path):
        """Sets the local_path of this FileShareServiceSpec.

        The path to the directory to share on the local file system. This should point to a directory, not a file. Use a slash ('/', U+002F) to separate directories within the path.   # noqa: E501

        :param local_path: The local_path of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and local_path is None:  # noqa: E501
            raise ValueError("Invalid value for `local_path`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                local_path is not None and len(local_path) > 4096):
            raise ValueError("Invalid value for `local_path`, length must be less than or equal to `4096`")  # noqa: E501

        self._local_path = local_path

    @property
    def connector_id(self):
        """Gets the connector_id of this FileShareServiceSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The connector_id of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """Sets the connector_id of this FileShareServiceSpec.

        Unique identifier  # noqa: E501

        :param connector_id: The connector_id of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and connector_id is None:  # noqa: E501
            raise ValueError("Invalid value for `connector_id`, must not be `None`")  # noqa: E501

        self._connector_id = connector_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileShareServiceSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileShareServiceSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from agilicus_api.api_client import ApiClient
from agilicus_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class GroupsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_group_member(self, group_id, add_group_member_request, **kwargs):  # noqa: E501
        """Add a group member  # noqa: E501

        Add a group member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_group_member(group_id, add_group_member_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param AddGroupMemberRequest add_group_member_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: User
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_group_member_with_http_info(group_id, add_group_member_request, **kwargs)  # noqa: E501

    def add_group_member_with_http_info(self, group_id, add_group_member_request, **kwargs):  # noqa: E501
        """Add a group member  # noqa: E501

        Add a group member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_group_member_with_http_info(group_id, add_group_member_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param AddGroupMemberRequest add_group_member_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(User, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'add_group_member_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_group_member" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `add_group_member`")  # noqa: E501
        # verify the required parameter 'add_group_member_request' is set
        if self.api_client.client_side_validation and ('add_group_member_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['add_group_member_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `add_group_member_request` when calling `add_group_member`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_group_member_request' in local_var_params:
            body_params = local_var_params['add_group_member_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}/members', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='User',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_group(self, group, **kwargs):  # noqa: E501
        """Create a group  # noqa: E501

        Create a group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_group(group, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Group group: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_group_with_http_info(group, **kwargs)  # noqa: E501

    def create_group_with_http_info(self, group, **kwargs):  # noqa: E501
        """Create a group  # noqa: E501

        Create a group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_group_with_http_info(group, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Group group: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Group, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group' is set
        if self.api_client.client_side_validation and ('group' not in local_var_params or  # noqa: E501
                                                        local_var_params['group'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group` when calling `create_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'group' in local_var_params:
            body_params = local_var_params['group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Group',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_group(self, group_id, **kwargs):  # noqa: E501
        """Delete a group  # noqa: E501

        Delete a group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_group_with_http_info(group_id, **kwargs)  # noqa: E501

    def delete_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Delete a group  # noqa: E501

        Delete a group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `delete_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_group_member(self, group_id, member_id, **kwargs):  # noqa: E501
        """Remove a group member  # noqa: E501

        Remove a group member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_member(group_id, member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str member_id: member_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_group_member_with_http_info(group_id, member_id, **kwargs)  # noqa: E501

    def delete_group_member_with_http_info(self, group_id, member_id, **kwargs):  # noqa: E501
        """Remove a group member  # noqa: E501

        Remove a group member  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_group_member_with_http_info(group_id, member_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str member_id: member_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'member_id', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_group_member" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `delete_group_member`")  # noqa: E501
        # verify the required parameter 'member_id' is set
        if self.api_client.client_side_validation and ('member_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['member_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `member_id` when calling `delete_group_member`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501
        if 'member_id' in local_var_params:
            path_params['member_id'] = local_var_params['member_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}/members/{member_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_group(self, group_id, **kwargs):  # noqa: E501
        """Get a group  # noqa: E501

        Get a group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_group_with_http_info(group_id, **kwargs)  # noqa: E501

    def get_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Get a group  # noqa: E501

        Get a group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param str org_id: Organisation Unique identifier
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Group, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `get_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Group',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_groups(self, **kwargs):  # noqa: E501
        """Get all groups  # noqa: E501

        Get all groups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str org_id: Organisation Unique identifier
        :param list[str] type: The type of groups to search for. Multiple values are ORed together.
        :param int limit: limit the number of rows in the response
        :param str previous_email: Pagination based query with the user's email as the key. To get the initial entries supply an empty string.
        :param str search_direction: Direction which the search should go starting from the email_nullable_query parameter. 
        :param str prefix_email_search: Keyword used to search for a list of users based on email. This parameter is case insensitive and finds users with an email that matches the keyword by its prefix. For example, if the keyword \"Foo\" is supplied to this parameter, users with emails of \"foo1@example.com\" and \"Foo2@test.com\" could be returned. 
        :param bool allow_partial_match: Perform a case insensitive partial match of any string query parameters included in the query 
        :param str first_name: query for users with a first name that matches the query parameter
        :param str last_name: query for users with a last name that matches the query parameter
        :param list[str] search_params: A list of strings to perform a case-insensitive search on all relevant fields in the database for a given collection. Multiple values are ANDed together 
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListGroupsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_groups_with_http_info(**kwargs)  # noqa: E501

    def list_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Get all groups  # noqa: E501

        Get all groups  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str org_id: Organisation Unique identifier
        :param list[str] type: The type of groups to search for. Multiple values are ORed together.
        :param int limit: limit the number of rows in the response
        :param str previous_email: Pagination based query with the user's email as the key. To get the initial entries supply an empty string.
        :param str search_direction: Direction which the search should go starting from the email_nullable_query parameter. 
        :param str prefix_email_search: Keyword used to search for a list of users based on email. This parameter is case insensitive and finds users with an email that matches the keyword by its prefix. For example, if the keyword \"Foo\" is supplied to this parameter, users with emails of \"foo1@example.com\" and \"Foo2@test.com\" could be returned. 
        :param bool allow_partial_match: Perform a case insensitive partial match of any string query parameters included in the query 
        :param str first_name: query for users with a first name that matches the query parameter
        :param str last_name: query for users with a last name that matches the query parameter
        :param list[str] search_params: A list of strings to perform a case-insensitive search on all relevant fields in the database for a given collection. Multiple values are ANDed together 
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListGroupsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['org_id', 'type', 'limit', 'previous_email', 'search_direction', 'prefix_email_search', 'allow_partial_match', 'first_name', 'last_name', 'search_params']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_groups" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 500:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_groups`, must be a value less than or equal to `500`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_groups`, must be a value greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('previous_email' in local_var_params and  # noqa: E501
                                                        len(local_var_params['previous_email']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `previous_email` when calling `list_groups`, length must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('previous_email' in local_var_params and  # noqa: E501
                                                        len(local_var_params['previous_email']) < 0):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `previous_email` when calling `list_groups`, length must be greater than or equal to `0`")  # noqa: E501
        if self.api_client.client_side_validation and ('prefix_email_search' in local_var_params and  # noqa: E501
                                                        len(local_var_params['prefix_email_search']) > 100):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `prefix_email_search` when calling `list_groups`, length must be less than or equal to `100`")  # noqa: E501
        if self.api_client.client_side_validation and ('prefix_email_search' in local_var_params and  # noqa: E501
                                                        len(local_var_params['prefix_email_search']) < 0):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `prefix_email_search` when calling `list_groups`, length must be greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'org_id' in local_var_params and local_var_params['org_id'] is not None:  # noqa: E501
            query_params.append(('org_id', local_var_params['org_id']))  # noqa: E501
        if 'type' in local_var_params and local_var_params['type'] is not None:  # noqa: E501
            query_params.append(('type', local_var_params['type']))  # noqa: E501
            collection_formats['type'] = 'multi'  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'previous_email' in local_var_params and local_var_params['previous_email'] is not None:  # noqa: E501
            query_params.append(('previous_email', local_var_params['previous_email']))  # noqa: E501
        if 'search_direction' in local_var_params and local_var_params['search_direction'] is not None:  # noqa: E501
            query_params.append(('search_direction', local_var_params['search_direction']))  # noqa: E501
        if 'prefix_email_search' in local_var_params and local_var_params['prefix_email_search'] is not None:  # noqa: E501
            query_params.append(('prefix_email_search', local_var_params['prefix_email_search']))  # noqa: E501
        if 'allow_partial_match' in local_var_params and local_var_params['allow_partial_match'] is not None:  # noqa: E501
            query_params.append(('allow_partial_match', local_var_params['allow_partial_match']))  # noqa: E501
        if 'first_name' in local_var_params and local_var_params['first_name'] is not None:  # noqa: E501
            query_params.append(('first_name', local_var_params['first_name']))  # noqa: E501
        if 'last_name' in local_var_params and local_var_params['last_name'] is not None:  # noqa: E501
            query_params.append(('last_name', local_var_params['last_name']))  # noqa: E501
        if 'search_params' in local_var_params and local_var_params['search_params'] is not None:  # noqa: E501
            query_params.append(('search_params', local_var_params['search_params']))  # noqa: E501
            collection_formats['search_params'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListGroupsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def replace_group(self, group_id, **kwargs):  # noqa: E501
        """update a group  # noqa: E501

        update a group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param Group group:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.replace_group_with_http_info(group_id, **kwargs)  # noqa: E501

    def replace_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """update a group  # noqa: E501

        update a group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str group_id: group_id path (required)
        :param Group group:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Group, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['group_id', 'group']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace_group" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['group_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `group_id` when calling `replace_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in local_var_params:
            path_params['group_id'] = local_var_params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'group' in local_var_params:
            body_params = local_var_params['group']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/groups/{group_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Group',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorSystemStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'os_version': 'str',
        'os_uptime': 'int',
        'agent_uptime': 'int',
        'agent_version': 'str',
        'agent_release_train': 'str',
        'agent_connector_id': 'str',
        'agent_connector_org_id': 'str'
    }

    attribute_map = {
        'os_version': 'os_version',
        'os_uptime': 'os_uptime',
        'agent_uptime': 'agent_uptime',
        'agent_version': 'agent_version',
        'agent_release_train': 'agent_release_train',
        'agent_connector_id': 'agent_connector_id',
        'agent_connector_org_id': 'agent_connector_org_id'
    }

    def __init__(self, os_version=None, os_uptime=None, agent_uptime=None, agent_version=None, agent_release_train=None, agent_connector_id=None, agent_connector_org_id=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorSystemStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._os_version = None
        self._os_uptime = None
        self._agent_uptime = None
        self._agent_version = None
        self._agent_release_train = None
        self._agent_connector_id = None
        self._agent_connector_org_id = None
        self.discriminator = None

        self.os_version = os_version
        self.os_uptime = os_uptime
        self.agent_uptime = agent_uptime
        self.agent_version = agent_version
        if agent_release_train is not None:
            self.agent_release_train = agent_release_train
        self.agent_connector_id = agent_connector_id
        self.agent_connector_org_id = agent_connector_org_id

    @property
    def os_version(self):
        """Gets the os_version of this AgentConnectorSystemStats.  # noqa: E501

        The version of the operating system on which the AgentConnector is running.  # noqa: E501

        :return: The os_version of this AgentConnectorSystemStats.  # noqa: E501
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """Sets the os_version of this AgentConnectorSystemStats.

        The version of the operating system on which the AgentConnector is running.  # noqa: E501

        :param os_version: The os_version of this AgentConnectorSystemStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and os_version is None:  # noqa: E501
            raise ValueError("Invalid value for `os_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                os_version is not None and len(os_version) > 2048):
            raise ValueError("Invalid value for `os_version`, length must be less than or equal to `2048`")  # noqa: E501

        self._os_version = os_version

    @property
    def os_uptime(self):
        """Gets the os_uptime of this AgentConnectorSystemStats.  # noqa: E501

        The length of time, in seconds, the operating system has been running.  # noqa: E501

        :return: The os_uptime of this AgentConnectorSystemStats.  # noqa: E501
        :rtype: int
        """
        return self._os_uptime

    @os_uptime.setter
    def os_uptime(self, os_uptime):
        """Sets the os_uptime of this AgentConnectorSystemStats.

        The length of time, in seconds, the operating system has been running.  # noqa: E501

        :param os_uptime: The os_uptime of this AgentConnectorSystemStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and os_uptime is None:  # noqa: E501
            raise ValueError("Invalid value for `os_uptime`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                os_uptime is not None and os_uptime < 0):  # noqa: E501
            raise ValueError("Invalid value for `os_uptime`, must be a value greater than or equal to `0`")  # noqa: E501

        self._os_uptime = os_uptime

    @property
    def agent_uptime(self):
        """Gets the agent_uptime of this AgentConnectorSystemStats.  # noqa: E501

        The length of time, in seconds, the AgentConnector has been running. If the AgentConnector restarts, this value will reset to zero.   # noqa: E501

        :return: The agent_uptime of this AgentConnectorSystemStats.  # noqa: E501
        :rtype: int
        """
        return self._agent_uptime

    @agent_uptime.setter
    def agent_uptime(self, agent_uptime):
        """Sets the agent_uptime of this AgentConnectorSystemStats.

        The length of time, in seconds, the AgentConnector has been running. If the AgentConnector restarts, this value will reset to zero.   # noqa: E501

        :param agent_uptime: The agent_uptime of this AgentConnectorSystemStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and agent_uptime is None:  # noqa: E501
            raise ValueError("Invalid value for `agent_uptime`, must not be `None`")  # noqa: E501

        self._agent_uptime = agent_uptime

    @property
    def agent_version(self):
        """Gets the agent_version of this AgentConnectorSystemStats.  # noqa: E501

        The version of software currently running for this AgentConnector. This includes both the version number and the commit reference from which it was built.   # noqa: E501

        :return: The agent_version of this AgentConnectorSystemStats.  # noqa: E501
        :rtype: str
        """
        return self._agent_version

    @agent_version.setter
    def agent_version(self, agent_version):
        """Sets the agent_version of this AgentConnectorSystemStats.

        The version of software currently running for this AgentConnector. This includes both the version number and the commit reference from which it was built.   # noqa: E501

        :param agent_version: The agent_version of this AgentConnectorSystemStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and agent_version is None:  # noqa: E501
            raise ValueError("Invalid value for `agent_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                agent_version is not None and len(agent_version) > 2048):
            raise ValueError("Invalid value for `agent_version`, length must be less than or equal to `2048`")  # noqa: E501

        self._agent_version = agent_version

    @property
    def agent_release_train(self):
        """Gets the agent_release_train of this AgentConnectorSystemStats.  # noqa: E501

        The release train followed by the AgentConnector. It uses this when checking for updates to determine which version of the AgentConnector should be installed.   # noqa: E501

        :return: The agent_release_train of this AgentConnectorSystemStats.  # noqa: E501
        :rtype: str
        """
        return self._agent_release_train

    @agent_release_train.setter
    def agent_release_train(self, agent_release_train):
        """Sets the agent_release_train of this AgentConnectorSystemStats.

        The release train followed by the AgentConnector. It uses this when checking for updates to determine which version of the AgentConnector should be installed.   # noqa: E501

        :param agent_release_train: The agent_release_train of this AgentConnectorSystemStats.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                agent_release_train is not None and len(agent_release_train) > 2048):
            raise ValueError("Invalid value for `agent_release_train`, length must be less than or equal to `2048`")  # noqa: E501

        self._agent_release_train = agent_release_train

    @property
    def agent_connector_id(self):
        """Gets the agent_connector_id of this AgentConnectorSystemStats.  # noqa: E501

        The identifier of the AgentConnector publishing these statistics. The AgentConnector publishes this information in order to ensure that an AgentConnector does not accidentally publish to the wrong endpoint.   # noqa: E501

        :return: The agent_connector_id of this AgentConnectorSystemStats.  # noqa: E501
        :rtype: str
        """
        return self._agent_connector_id

    @agent_connector_id.setter
    def agent_connector_id(self, agent_connector_id):
        """Sets the agent_connector_id of this AgentConnectorSystemStats.

        The identifier of the AgentConnector publishing these statistics. The AgentConnector publishes this information in order to ensure that an AgentConnector does not accidentally publish to the wrong endpoint.   # noqa: E501

        :param agent_connector_id: The agent_connector_id of this AgentConnectorSystemStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and agent_connector_id is None:  # noqa: E501
            raise ValueError("Invalid value for `agent_connector_id`, must not be `None`")  # noqa: E501

        self._agent_connector_id = agent_connector_id

    @property
    def agent_connector_org_id(self):
        """Gets the agent_connector_org_id of this AgentConnectorSystemStats.  # noqa: E501

        The organisation identifier of the AgentConnector publishing these statistics. The AgentConnector publishes this information in order to ensure that an AgentConnector does not accidentally publish to the wrong endpoint.   # noqa: E501

        :return: The agent_connector_org_id of this AgentConnectorSystemStats.  # noqa: E501
        :rtype: str
        """
        return self._agent_connector_org_id

    @agent_connector_org_id.setter
    def agent_connector_org_id(self, agent_connector_org_id):
        """Sets the agent_connector_org_id of this AgentConnectorSystemStats.

        The organisation identifier of the AgentConnector publishing these statistics. The AgentConnector publishes this information in order to ensure that an AgentConnector does not accidentally publish to the wrong endpoint.   # noqa: E501

        :param agent_connector_org_id: The agent_connector_org_id of this AgentConnectorSystemStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and agent_connector_org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `agent_connector_org_id`, must not be `None`")  # noqa: E501

        self._agent_connector_org_id = agent_connector_org_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorSystemStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorSystemStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.tokens_api import TokensApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestTokensApi(unittest.TestCase):
    """TokensApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.tokens_api.TokensApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_api_key(self):
        """Test case for create_api_key

        Create an API Key  # noqa: E501
        """
        pass

    def test_create_api_key_introspection(self):
        """Test case for create_api_key_introspection

        Introspect an API Key  # noqa: E501
        """
        pass

    def test_create_authentication_document(self):
        """Test case for create_authentication_document

        Create a authentication document  # noqa: E501
        """
        pass

    def test_create_introspect_token(self):
        """Test case for create_introspect_token

        Introspect a token  # noqa: E501
        """
        pass

    def test_create_introspect_token_all_sub_orgs(self):
        """Test case for create_introspect_token_all_sub_orgs

        Introspect a token in all sub orgs  # noqa: E501
        """
        pass

    def test_create_reissued_token(self):
        """Test case for create_reissued_token

        Issue a new token from another  # noqa: E501
        """
        pass

    def test_create_revoke_token_task(self):
        """Test case for create_revoke_token_task

        Revoke a token  # noqa: E501
        """
        pass

    def test_create_token(self):
        """Test case for create_token

        Create a token  # noqa: E501
        """
        pass

    def test_create_token_validation(self):
        """Test case for create_token_validation

        Validate a token request  # noqa: E501
        """
        pass

    def test_delete_api_key(self):
        """Test case for delete_api_key

        Delete an API Key  # noqa: E501
        """
        pass

    def test_delete_authentication_document(self):
        """Test case for delete_authentication_document

        Delete a authentication document  # noqa: E501
        """
        pass

    def test_get_api_key(self):
        """Test case for get_api_key

        Get an API Key  # noqa: E501
        """
        pass

    def test_get_authentication_document(self):
        """Test case for get_authentication_document

        Get a authentication document  # noqa: E501
        """
        pass

    def test_list_api_keys(self):
        """Test case for list_api_keys

        List API Keys  # noqa: E501
        """
        pass

    def test_list_authentication_documents(self):
        """Test case for list_authentication_documents

        List authentication documents  # noqa: E501
        """
        pass

    def test_list_tokens(self):
        """Test case for list_tokens

        Query tokens  # noqa: E501
        """
        pass

    def test_validate_identity_assertion(self):
        """Test case for validate_identity_assertion

        Validate an identity assertion  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.secure_agent import SecureAgent  # noqa: E501
from agilicus_api.rest import ApiException

class TestSecureAgent(unittest.TestCase):
    """SecureAgent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SecureAgent
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.secure_agent.SecureAgent()  # noqa: E501
        if include_optional :
            return SecureAgent(
                metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                spec = agilicus_api.models.secure_agent_spec.SecureAgentSpec(
                    name = '0', 
                    org_id = '123', 
                    application_service_ids = [
                        '123'
                        ], 
                    connectors = [
                        agilicus_api.models.secure_agent_connector.SecureAgentConnector(
                            max_number_connections = 0, 
                            connection_uri = '0', )
                        ], ), 
                status = agilicus_api.models.secure_agent_status.SecureAgentStatus(
                    application_services = [
                        agilicus_api.models.application_service.ApplicationService(
                            created = '2015-07-07T15:49:51.230+02:00', 
                            id = '123', 
                            name = '0', 
                            org_id = '0', 
                            hostname = 'db.example.com', 
                            ipv4_addresses = [
                                '192.0.2.1'
                                ], 
                            name_resolution = 'static', 
                            port = 56, 
                            protocol = 'tcp', 
                            assignments = [
                                agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                    app_id = '0', 
                                    environment_name = '0', 
                                    org_id = '0', )
                                ], 
                            updated = '2015-07-07T15:49:51.230+02:00', 
                            service_type = 'vpn', 
                            service_protocol_type = 'ip', 
                            connector_id = '123', )
                        ], 
                    connector_info = [
                        agilicus_api.models.secure_agent_connector_info.SecureAgentConnectorInfo(
                            connection_uri = '0', 
                            max_number_connections = 0, )
                        ], )
            )
        else :
            return SecureAgent(
                spec = agilicus_api.models.secure_agent_spec.SecureAgentSpec(
                    name = '0', 
                    org_id = '123', 
                    application_service_ids = [
                        '123'
                        ], 
                    connectors = [
                        agilicus_api.models.secure_agent_connector.SecureAgentConnector(
                            max_number_connections = 0, 
                            connection_uri = '0', )
                        ], ),
        )

    def testSecureAgent(self):
        """Test SecureAgent"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_applications_response import ListApplicationsResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListApplicationsResponse(unittest.TestCase):
    """ListApplicationsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListApplicationsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_applications_response.ListApplicationsResponse()  # noqa: E501
        if include_optional :
            return ListApplicationsResponse(
                applications = [
                    agilicus_api.models.application.Application(
                        created = '2015-07-07T15:49:51.230+02:00', 
                        id = '123', 
                        name = 'a', 
                        description = '0', 
                        category = '0', 
                        image = '0', 
                        image_username = '0', 
                        image_password = '0', 
                        image_credentials_type = 'basic_auth', 
                        environments = [
                            agilicus_api.models.environment.Environment(
                                created = '2015-07-07T15:49:51.230+02:00', 
                                name = '0', 
                                maintenance_org_id = '0', 
                                domain_aliases = [
                                    'a'
                                    ], 
                                version_tag = '0', 
                                config_mount_path = '0', 
                                config_as_mount = '0', 
                                config_as_env = '0', 
                                secrets_mount_path = '0', 
                                secrets_as_mount = '0', 
                                secrets_as_env = '0', 
                                application_services = [
                                    agilicus_api.models.application_service.ApplicationService(
                                        id = '123', 
                                        name = '0', 
                                        org_id = '0', 
                                        hostname = 'db.example.com', 
                                        ipv4_addresses = [
                                            '192.0.2.1'
                                            ], 
                                        name_resolution = 'static', 
                                        port = 56, 
                                        protocol = 'tcp', 
                                        assignments = [
                                            agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                                app_id = '0', 
                                                environment_name = '0', 
                                                org_id = '0', )
                                            ], 
                                        updated = '2015-07-07T15:49:51.230+02:00', 
                                        service_type = 'vpn', 
                                        service_protocol_type = 'ip', 
                                        connector_id = '123', )
                                    ], 
                                serverless_image = '0', 
                                status = agilicus_api.models.environment_status.EnvironmentStatus(
                                    runtime_status = agilicus_api.models.runtime_status.RuntimeStatus(
                                        overall_status = 'good', 
                                        running_replicas = 2, 
                                        error_message = 'CrashLoopBackoff', 
                                        restarts = 5, 
                                        cpu = 0.6, 
                                        memory = 45.2, 
                                        last_apply_time = '2002-10-02T10:00-05:00', 
                                        running_image = 'cr.agilicus.com/applications/iomad:v1.13.0', 
                                        running_hash = 'sha256:2fb759c1adfe40863b89a4076111af8f210e7342d2240f09b08fc445b357112e', 
                                        org_id = '123', ), ), 
                                updated = '2015-07-07T15:49:51.230+02:00', 
                                application_configs = agilicus_api.models.application_config.ApplicationConfig(
                                    authentication_config = agilicus_api.models.application_authentication_config.ApplicationAuthenticationConfig(
                                        application_handles_authentication = False, ), 
                                    oidc_config = agilicus_api.models.oidc_proxy_config.OIDCProxyConfig(
                                        headers = agilicus_api.models.oidc_proxy_header.OIDCProxyHeader(
                                            domain_substitution = agilicus_api.models.oidc_proxy_domain_substitution.OIDCProxyDomainSubstitution(
                                                standard_headers = agilicus_api.models.oidc_proxy_standard_header.OIDCProxyStandardHeader(
                                                    location = True, 
                                                    origin = True, 
                                                    host = True, ), 
                                                other_headers = [
                                                    agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                        name = 'Accept-Encoding', 
                                                        value = '*', )
                                                    ], ), 
                                            header_overrides = agilicus_api.models.oidc_proxy_header_override.OIDCProxyHeaderOverride(
                                                request = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(
                                                    set = [
                                                        agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                            name = 'Accept-Encoding', 
                                                            value = '*', )
                                                        ], 
                                                    add = [
                                                        agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                                            name = 'Accept-Encoding', 
                                                            value = '*', )
                                                        ], 
                                                    remove = [
                                                        agilicus_api.models.oidc_proxy_header_name.OIDCProxyHeaderName(
                                                            name = '0', )
                                                        ], ), 
                                                response = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(), ), ), 
                                        domain_mapping = agilicus_api.models.oidc_proxy_domain_mapping.OIDCProxyDomainMapping(
                                            primary_external_name = 'app-1.cloud.egov.city', 
                                            primary_internal_name = 'app-1.internal', 
                                            other_mappings = [
                                                agilicus_api.models.oidc_proxy_domain_name_mapping.OIDCProxyDomainNameMapping(
                                                    internal_name = 'local_test_app', 
                                                    external_name = 'app-1', )
                                                ], ), 
                                        auth = agilicus_api.models.oidc_auth_config.OIDCAuthConfig(
                                            auth_enabled = True, 
                                            client_id = 'admin-portal', 
                                            issuer = 'https://auth.cloud.egov.city', 
                                            logout_url = '/login/logout.cfm', 
                                            scopes = [
                                                agilicus_api.models.oidc_proxy_scope.OIDCProxyScope(
                                                    name = 'urn:agilicus:app:app-1:owner', )
                                                ], 
                                            path_config = agilicus_api.models.oidc_auth_path_config.OIDCAuthPathConfig(
                                                included_paths = [{"path":"/login"}], 
                                                excluded_paths = [{"path":"/logout"}], ), ), 
                                        content_manipulation = agilicus_api.models.oidc_proxy_content_manipulation.OIDCProxyContentManipulation(
                                            media_types = [
                                                agilicus_api.models.oidc_content_type.OIDCContentType(
                                                    name = 'text/css', )
                                                ], ), 
                                        upstream_config = agilicus_api.models.oidc_proxy_upstream_config.OIDCProxyUpstreamConfig(
                                            scheme = 'https', 
                                            hostname = 'httpbin.org', ), ), ), )
                            ], 
                        org_id = '0', 
                        contact_email = '0', 
                        monitoring_config = agilicus_api.models.application_monitoring_config.ApplicationMonitoringConfig(
                            port = 1, 
                            path = '/metrics', ), 
                        port = 56, 
                        healthcheck_uri = '0', 
                        roles = [
                            agilicus_api.models.role.Role(
                                name = '0', 
                                rules = [
                                    agilicus_api.models.rule.Rule(
                                        host = '0', 
                                        name = 'rules.add', 
                                        method = 'get', 
                                        path = '/.*', 
                                        query_parameters = [
                                            agilicus_api.models.rule_query_parameter.RuleQueryParameter(
                                                name = '0', 
                                                exact_match = '0', )
                                            ], 
                                        body = agilicus_api.models.rule_query_body.RuleQueryBody(
                                            json = [
                                                agilicus_api.models.rule_query_body_json.RuleQueryBodyJSON(
                                                    name = '0', 
                                                    exact_match = '0', 
                                                    match_type = 'string', 
                                                    pointer = '/foo/0/a~1b/2', )
                                                ], ), )
                                    ], )
                            ], 
                        definitions = [
                            agilicus_api.models.definition.Definition(
                                key = '0', 
                                value = '0', )
                            ], 
                        assignments = [
                            agilicus_api.models.application_assignment.ApplicationAssignment(
                                id = '0', 
                                org_id = 'asd901laskbh', 
                                environment_name = 'production', 
                                application_name = 'Blogs', )
                            ], 
                        owned = True, 
                        maintained = True, 
                        assigned = True, 
                        published = 'no', 
                        default_role_id = 'AcaSL40fs22l4Dr4XoAd5y', 
                        default_role_name = 'owner', 
                        icon_url = '0', 
                        updated = '2015-07-07T15:49:51.230+02:00', 
                        location = 'hosted', 
                        service_account_id = '0', 
                        service_account_required = True, 
                        application_type = 'user_defined', )
                    ]
            )
        else :
            return ListApplicationsResponse(
        )

    def testListApplicationsResponse(self):
        """Test ListApplicationsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.user_application_access_info import UserApplicationAccessInfo  # noqa: E501
from agilicus_api.rest import ApiException

class TestUserApplicationAccessInfo(unittest.TestCase):
    """UserApplicationAccessInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserApplicationAccessInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.user_application_access_info.UserApplicationAccessInfo()  # noqa: E501
        if include_optional :
            return UserApplicationAccessInfo(
                status = agilicus_api.models.user_application_access_info_status.UserApplicationAccessInfoStatus(
                    user_id = 'tuU7smH86zAXMl76sua6xQ', 
                    org_id = 'IAsl3dl40aSsfLKiU76', 
                    org_name = 'egov', 
                    parent_org_id = 'G99q3lasls29wsk', 
                    parent_org_name = 'root', 
                    application_name = 'parking', 
                    application_url = 'https://parking.cloud.egov.city', 
                    application_description = 'An application to submit parking requests', 
                    application_category = 'citizen-facing', 
                    icon_url = 'https://storage.googleapis.com/agilicus/logo.svg', 
                    access_level = 'requested', 
                    application_default_role_name = 'self', 
                    application_default_role_id = 'as0Z6fXFsl23', 
                    roles = [
                        '0'
                        ], )
            )
        else :
            return UserApplicationAccessInfo(
                status = agilicus_api.models.user_application_access_info_status.UserApplicationAccessInfoStatus(
                    user_id = 'tuU7smH86zAXMl76sua6xQ', 
                    org_id = 'IAsl3dl40aSsfLKiU76', 
                    org_name = 'egov', 
                    parent_org_id = 'G99q3lasls29wsk', 
                    parent_org_name = 'root', 
                    application_name = 'parking', 
                    application_url = 'https://parking.cloud.egov.city', 
                    application_description = 'An application to submit parking requests', 
                    application_category = 'citizen-facing', 
                    icon_url = 'https://storage.googleapis.com/agilicus/logo.svg', 
                    access_level = 'requested', 
                    application_default_role_name = 'self', 
                    application_default_role_id = 'as0Z6fXFsl23', 
                    roles = [
                        '0'
                        ], ),
        )

    def testUserApplicationAccessInfo(self):
        """Test UserApplicationAccessInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class Message(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'title': 'str',
        'sub_header': 'str',
        'icon': 'str',
        'image': 'str',
        'text': 'str',
        'uri': 'str',
        'context': 'str',
        'actions': 'list[MessageAction]'
    }

    attribute_map = {
        'id': 'id',
        'title': 'title',
        'sub_header': 'sub_header',
        'icon': 'icon',
        'image': 'image',
        'text': 'text',
        'uri': 'uri',
        'context': 'context',
        'actions': 'actions'
    }

    def __init__(self, id=None, title=None, sub_header=None, icon=None, image=None, text=None, uri=None, context=None, actions=None, local_vars_configuration=None):  # noqa: E501
        """Message - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._title = None
        self._sub_header = None
        self._icon = None
        self._image = None
        self._text = None
        self._uri = None
        self._context = None
        self._actions = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if title is not None:
            self.title = title
        if sub_header is not None:
            self.sub_header = sub_header
        if icon is not None:
            self.icon = icon
        if image is not None:
            self.image = image
        self.text = text
        if uri is not None:
            self.uri = uri
        if context is not None:
            self.context = context
        if actions is not None:
            self.actions = actions

    @property
    def id(self):
        """Gets the id of this Message.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The id of this Message.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Message.

        Unique identifier  # noqa: E501

        :param id: The id of this Message.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def title(self):
        """Gets the title of this Message.  # noqa: E501

        The title of the message (if medium allows)  # noqa: E501

        :return: The title of this Message.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Message.

        The title of the message (if medium allows)  # noqa: E501

        :param title: The title of this Message.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                title is not None and len(title) > 100):
            raise ValueError("Invalid value for `title`, length must be less than or equal to `100`")  # noqa: E501

        self._title = title

    @property
    def sub_header(self):
        """Gets the sub_header of this Message.  # noqa: E501

        The sub-header of the message (if medium allows)  # noqa: E501

        :return: The sub_header of this Message.  # noqa: E501
        :rtype: str
        """
        return self._sub_header

    @sub_header.setter
    def sub_header(self, sub_header):
        """Sets the sub_header of this Message.

        The sub-header of the message (if medium allows)  # noqa: E501

        :param sub_header: The sub_header of this Message.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                sub_header is not None and len(sub_header) > 100):
            raise ValueError("Invalid value for `sub_header`, length must be less than or equal to `100`")  # noqa: E501

        self._sub_header = sub_header

    @property
    def icon(self):
        """Gets the icon of this Message.  # noqa: E501

        The icon (uri) of the message (if medium allows)  # noqa: E501

        :return: The icon of this Message.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this Message.

        The icon (uri) of the message (if medium allows)  # noqa: E501

        :param icon: The icon of this Message.  # noqa: E501
        :type: str
        """

        self._icon = icon

    @property
    def image(self):
        """Gets the image of this Message.  # noqa: E501

        The image (uri) of the message (if medium allows)  # noqa: E501

        :return: The image of this Message.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this Message.

        The image (uri) of the message (if medium allows)  # noqa: E501

        :param image: The image of this Message.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def text(self):
        """Gets the text of this Message.  # noqa: E501

        The text string of the message  # noqa: E501

        :return: The text of this Message.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Message.

        The text string of the message  # noqa: E501

        :param text: The text of this Message.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and text is None:  # noqa: E501
            raise ValueError("Invalid value for `text`, must not be `None`")  # noqa: E501

        self._text = text

    @property
    def uri(self):
        """Gets the uri of this Message.  # noqa: E501

        The overall uri of the message (eg if clicked on). In some medium (e.g. Chrome WebPush) we can have individual actions, in others (e.g. Firefox WebPush) we only get the entire message as link.   # noqa: E501

        :return: The uri of this Message.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this Message.

        The overall uri of the message (eg if clicked on). In some medium (e.g. Chrome WebPush) we can have individual actions, in others (e.g. Firefox WebPush) we only get the entire message as link.   # noqa: E501

        :param uri: The uri of this Message.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def context(self):
        """Gets the context of this Message.  # noqa: E501

        A blob of context, message-type dependent  # noqa: E501

        :return: The context of this Message.  # noqa: E501
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this Message.

        A blob of context, message-type dependent  # noqa: E501

        :param context: The context of this Message.  # noqa: E501
        :type: str
        """

        self._context = context

    @property
    def actions(self):
        """Gets the actions of this Message.  # noqa: E501

        A list of action buttons (if supported)  # noqa: E501

        :return: The actions of this Message.  # noqa: E501
        :rtype: list[MessageAction]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """Sets the actions of this Message.

        A list of action buttons (if supported)  # noqa: E501

        :param actions: The actions of this Message.  # noqa: E501
        :type: list[MessageAction]
        """

        self._actions = actions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Message):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Message):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorPerShareStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'share_prefix': 'str',
        'share_id': 'str',
        'local_path': 'str',
        'total_requests': 'int',
        'successful_requests': 'int',
        'failed_requests': 'int',
        'bytes_sent': 'int',
        'bytes_received': 'int',
        'share_start_time': 'datetime'
    }

    attribute_map = {
        'share_prefix': 'share_prefix',
        'share_id': 'share_id',
        'local_path': 'local_path',
        'total_requests': 'total_requests',
        'successful_requests': 'successful_requests',
        'failed_requests': 'failed_requests',
        'bytes_sent': 'bytes_sent',
        'bytes_received': 'bytes_received',
        'share_start_time': 'share_start_time'
    }

    def __init__(self, share_prefix=None, share_id=None, local_path=None, total_requests=None, successful_requests=None, failed_requests=None, bytes_sent=None, bytes_received=None, share_start_time=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorPerShareStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._share_prefix = None
        self._share_id = None
        self._local_path = None
        self._total_requests = None
        self._successful_requests = None
        self._failed_requests = None
        self._bytes_sent = None
        self._bytes_received = None
        self._share_start_time = None
        self.discriminator = None

        self.share_prefix = share_prefix
        self.share_id = share_id
        self.local_path = local_path
        self.total_requests = total_requests
        self.successful_requests = successful_requests
        self.failed_requests = failed_requests
        self.bytes_sent = bytes_sent
        self.bytes_received = bytes_received
        self.share_start_time = share_start_time

    @property
    def share_prefix(self):
        """Gets the share_prefix of this AgentConnectorPerShareStats.  # noqa: E501

        The prefix used to route the requests to the shared local path. This is typically derived from the share_name of the Share.   # noqa: E501

        :return: The share_prefix of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: str
        """
        return self._share_prefix

    @share_prefix.setter
    def share_prefix(self, share_prefix):
        """Sets the share_prefix of this AgentConnectorPerShareStats.

        The prefix used to route the requests to the shared local path. This is typically derived from the share_name of the Share.   # noqa: E501

        :param share_prefix: The share_prefix of this AgentConnectorPerShareStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and share_prefix is None:  # noqa: E501
            raise ValueError("Invalid value for `share_prefix`, must not be `None`")  # noqa: E501

        self._share_prefix = share_prefix

    @property
    def share_id(self):
        """Gets the share_id of this AgentConnectorPerShareStats.  # noqa: E501

        The unique ID of the FileShareService to which this share corresponds.   # noqa: E501

        :return: The share_id of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: str
        """
        return self._share_id

    @share_id.setter
    def share_id(self, share_id):
        """Sets the share_id of this AgentConnectorPerShareStats.

        The unique ID of the FileShareService to which this share corresponds.   # noqa: E501

        :param share_id: The share_id of this AgentConnectorPerShareStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and share_id is None:  # noqa: E501
            raise ValueError("Invalid value for `share_id`, must not be `None`")  # noqa: E501

        self._share_id = share_id

    @property
    def local_path(self):
        """Gets the local_path of this AgentConnectorPerShareStats.  # noqa: E501

        The path on the local file system which is being shared.  # noqa: E501

        :return: The local_path of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: str
        """
        return self._local_path

    @local_path.setter
    def local_path(self, local_path):
        """Sets the local_path of this AgentConnectorPerShareStats.

        The path on the local file system which is being shared.  # noqa: E501

        :param local_path: The local_path of this AgentConnectorPerShareStats.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and local_path is None:  # noqa: E501
            raise ValueError("Invalid value for `local_path`, must not be `None`")  # noqa: E501

        self._local_path = local_path

    @property
    def total_requests(self):
        """Gets the total_requests of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of requests made to this share.  # noqa: E501

        :return: The total_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._total_requests

    @total_requests.setter
    def total_requests(self, total_requests):
        """Sets the total_requests of this AgentConnectorPerShareStats.

        The total number of requests made to this share.  # noqa: E501

        :param total_requests: The total_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_requests is None:  # noqa: E501
            raise ValueError("Invalid value for `total_requests`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                total_requests is not None and total_requests < 0):  # noqa: E501
            raise ValueError("Invalid value for `total_requests`, must be a value greater than or equal to `0`")  # noqa: E501

        self._total_requests = total_requests

    @property
    def successful_requests(self):
        """Gets the successful_requests of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of requests which have succeeded.  # noqa: E501

        :return: The successful_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._successful_requests

    @successful_requests.setter
    def successful_requests(self, successful_requests):
        """Sets the successful_requests of this AgentConnectorPerShareStats.

        The total number of requests which have succeeded.  # noqa: E501

        :param successful_requests: The successful_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and successful_requests is None:  # noqa: E501
            raise ValueError("Invalid value for `successful_requests`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                successful_requests is not None and successful_requests < 0):  # noqa: E501
            raise ValueError("Invalid value for `successful_requests`, must be a value greater than or equal to `0`")  # noqa: E501

        self._successful_requests = successful_requests

    @property
    def failed_requests(self):
        """Gets the failed_requests of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of requests which have failed.  # noqa: E501

        :return: The failed_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._failed_requests

    @failed_requests.setter
    def failed_requests(self, failed_requests):
        """Sets the failed_requests of this AgentConnectorPerShareStats.

        The total number of requests which have failed.  # noqa: E501

        :param failed_requests: The failed_requests of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_requests is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_requests`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                failed_requests is not None and failed_requests < 0):  # noqa: E501
            raise ValueError("Invalid value for `failed_requests`, must be a value greater than or equal to `0`")  # noqa: E501

        self._failed_requests = failed_requests

    @property
    def bytes_sent(self):
        """Gets the bytes_sent of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of bytes sent in the body of responses to requests. This includes any metadata about files, or data included in failure responses.   # noqa: E501

        :return: The bytes_sent of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._bytes_sent

    @bytes_sent.setter
    def bytes_sent(self, bytes_sent):
        """Sets the bytes_sent of this AgentConnectorPerShareStats.

        The total number of bytes sent in the body of responses to requests. This includes any metadata about files, or data included in failure responses.   # noqa: E501

        :param bytes_sent: The bytes_sent of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and bytes_sent is None:  # noqa: E501
            raise ValueError("Invalid value for `bytes_sent`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bytes_sent is not None and bytes_sent < 0):  # noqa: E501
            raise ValueError("Invalid value for `bytes_sent`, must be a value greater than or equal to `0`")  # noqa: E501

        self._bytes_sent = bytes_sent

    @property
    def bytes_received(self):
        """Gets the bytes_received of this AgentConnectorPerShareStats.  # noqa: E501

        The total number of bytes received in the body of requests. This includes any metadata about files, files themselves, or general commands such as lock requests.   # noqa: E501

        :return: The bytes_received of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: int
        """
        return self._bytes_received

    @bytes_received.setter
    def bytes_received(self, bytes_received):
        """Sets the bytes_received of this AgentConnectorPerShareStats.

        The total number of bytes received in the body of requests. This includes any metadata about files, files themselves, or general commands such as lock requests.   # noqa: E501

        :param bytes_received: The bytes_received of this AgentConnectorPerShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and bytes_received is None:  # noqa: E501
            raise ValueError("Invalid value for `bytes_received`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                bytes_received is not None and bytes_received < 0):  # noqa: E501
            raise ValueError("Invalid value for `bytes_received`, must be a value greater than or equal to `0`")  # noqa: E501

        self._bytes_received = bytes_received

    @property
    def share_start_time(self):
        """Gets the share_start_time of this AgentConnectorPerShareStats.  # noqa: E501

        When the share was started.  # noqa: E501

        :return: The share_start_time of this AgentConnectorPerShareStats.  # noqa: E501
        :rtype: datetime
        """
        return self._share_start_time

    @share_start_time.setter
    def share_start_time(self, share_start_time):
        """Sets the share_start_time of this AgentConnectorPerShareStats.

        When the share was started.  # noqa: E501

        :param share_start_time: The share_start_time of this AgentConnectorPerShareStats.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and share_start_time is None:  # noqa: E501
            raise ValueError("Invalid value for `share_start_time`, must not be `None`")  # noqa: E501

        self._share_start_time = share_start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorPerShareStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorPerShareStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.16
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from agilicus_api.api_client import ApiClient
from agilicus_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class MessagesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_message(self, message_endpoint_id, message, **kwargs):  # noqa: E501
        """Send a message to a specific message endpoint.  # noqa: E501

        Send a message to a specific message endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_message(message_endpoint_id, message, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str message_endpoint_id: send a message on a message endpoint (required)
        :param Message message: Message (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Message
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_message_with_http_info(message_endpoint_id, message, **kwargs)  # noqa: E501

    def create_message_with_http_info(self, message_endpoint_id, message, **kwargs):  # noqa: E501
        """Send a message to a specific message endpoint.  # noqa: E501

        Send a message to a specific message endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_message_with_http_info(message_endpoint_id, message, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str message_endpoint_id: send a message on a message endpoint (required)
        :param Message message: Message (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Message, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['message_endpoint_id', 'message']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_message" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'message_endpoint_id' is set
        if self.api_client.client_side_validation and ('message_endpoint_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['message_endpoint_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message_endpoint_id` when calling `create_message`")  # noqa: E501
        # verify the required parameter 'message' is set
        if self.api_client.client_side_validation and ('message' not in local_var_params or  # noqa: E501
                                                        local_var_params['message'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message` when calling `create_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'message_endpoint_id' in local_var_params:
            path_params['message_endpoint_id'] = local_var_params['message_endpoint_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'message' in local_var_params:
            body_params = local_var_params['message']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/messages/{message_endpoint_id}/send', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Message',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_user_message(self, user_id, message, **kwargs):  # noqa: E501
        """Send a message to a user on all (optionally of a type) endpoints.  # noqa: E501

        Send a message to a user on all (optionally of a type) endpoints.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_message(user_id, message, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: user_id path (required)
        :param Message message: Message (required)
        :param MessageEndpointType message_endpoint_type: messaging endpoint type
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Message
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_user_message_with_http_info(user_id, message, **kwargs)  # noqa: E501

    def create_user_message_with_http_info(self, user_id, message, **kwargs):  # noqa: E501
        """Send a message to a user on all (optionally of a type) endpoints.  # noqa: E501

        Send a message to a user on all (optionally of a type) endpoints.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_message_with_http_info(user_id, message, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: user_id path (required)
        :param Message message: Message (required)
        :param MessageEndpointType message_endpoint_type: messaging endpoint type
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Message, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id', 'message', 'message_endpoint_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user_message" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_id` when calling `create_user_message`")  # noqa: E501
        # verify the required parameter 'message' is set
        if self.api_client.client_side_validation and ('message' not in local_var_params or  # noqa: E501
                                                        local_var_params['message'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message` when calling `create_user_message`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in local_var_params:
            path_params['user_id'] = local_var_params['user_id']  # noqa: E501

        query_params = []
        if 'message_endpoint_type' in local_var_params and local_var_params['message_endpoint_type'] is not None:  # noqa: E501
            query_params.append(('message_endpoint_type', local_var_params['message_endpoint_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'message' in local_var_params:
            body_params = local_var_params['message']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/messages/user/{user_id}/send', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Message',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_message_endpoint(self, message_endpoint_id, **kwargs):  # noqa: E501
        """Delete a messaging endpoint  # noqa: E501

        Delete a messaging endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_message_endpoint(message_endpoint_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str message_endpoint_id: messaging endpoint id (required)
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_message_endpoint_with_http_info(message_endpoint_id, **kwargs)  # noqa: E501

    def delete_message_endpoint_with_http_info(self, message_endpoint_id, **kwargs):  # noqa: E501
        """Delete a messaging endpoint  # noqa: E501

        Delete a messaging endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_message_endpoint_with_http_info(message_endpoint_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str message_endpoint_id: messaging endpoint id (required)
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['message_endpoint_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_message_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'message_endpoint_id' is set
        if self.api_client.client_side_validation and ('message_endpoint_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['message_endpoint_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message_endpoint_id` when calling `delete_message_endpoint`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'message_endpoint_id' in local_var_params:
            path_params['message_endpoint_id'] = local_var_params['message_endpoint_id']  # noqa: E501

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/messages/{message_endpoint_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_message_endpoint(self, message_endpoint_id, **kwargs):  # noqa: E501
        """Get a message endpoint  # noqa: E501

        Get a message endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_message_endpoint(message_endpoint_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str message_endpoint_id: messaging endpoint id (required)
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MessageEndpoint
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_message_endpoint_with_http_info(message_endpoint_id, **kwargs)  # noqa: E501

    def get_message_endpoint_with_http_info(self, message_endpoint_id, **kwargs):  # noqa: E501
        """Get a message endpoint  # noqa: E501

        Get a message endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_message_endpoint_with_http_info(message_endpoint_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str message_endpoint_id: messaging endpoint id (required)
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MessageEndpoint, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['message_endpoint_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_message_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'message_endpoint_id' is set
        if self.api_client.client_side_validation and ('message_endpoint_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['message_endpoint_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message_endpoint_id` when calling `get_message_endpoint`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'message_endpoint_id' in local_var_params:
            path_params['message_endpoint_id'] = local_var_params['message_endpoint_id']  # noqa: E501

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/messages/{message_endpoint_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MessageEndpoint',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_message_endpoints(self, **kwargs):  # noqa: E501
        """List all message endpoints (all users or a single user)  # noqa: E501

        List all message endpoints (all users or a single user)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_message_endpoints(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: Query based on user id
        :param int limit: limit the number of rows in the response
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListMessageEndpointsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_message_endpoints_with_http_info(**kwargs)  # noqa: E501

    def list_message_endpoints_with_http_info(self, **kwargs):  # noqa: E501
        """List all message endpoints (all users or a single user)  # noqa: E501

        List all message endpoints (all users or a single user)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_message_endpoints_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: Query based on user id
        :param int limit: limit the number of rows in the response
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListMessageEndpointsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_message_endpoints" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 500:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_message_endpoints`, must be a value less than or equal to `500`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_message_endpoints`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/messages', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListMessageEndpointsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_messages_config(self, **kwargs):  # noqa: E501
        """Get the config of the endpoint-types (e.g. public keys etc).  # noqa: E501

        Get the config of the endpoint-types (e.g. public keys etc).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_messages_config(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MessageEndpointsConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_messages_config_with_http_info(**kwargs)  # noqa: E501

    def list_messages_config_with_http_info(self, **kwargs):  # noqa: E501
        """Get the config of the endpoint-types (e.g. public keys etc).  # noqa: E501

        Get the config of the endpoint-types (e.g. public keys etc).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_messages_config_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MessageEndpointsConfig, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_messages_config" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/messages/config', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MessageEndpointsConfig',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def replace_message_endpoint(self, message_endpoint_id, message_endpoint, **kwargs):  # noqa: E501
        """Update a messaging endpoint  # noqa: E501

        Update a messaging endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_message_endpoint(message_endpoint_id, message_endpoint, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str message_endpoint_id: messaging endpoint id (required)
        :param MessageEndpoint message_endpoint: Message (required)
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MessageEndpoint
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.replace_message_endpoint_with_http_info(message_endpoint_id, message_endpoint, **kwargs)  # noqa: E501

    def replace_message_endpoint_with_http_info(self, message_endpoint_id, message_endpoint, **kwargs):  # noqa: E501
        """Update a messaging endpoint  # noqa: E501

        Update a messaging endpoint  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_message_endpoint_with_http_info(message_endpoint_id, message_endpoint, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str message_endpoint_id: messaging endpoint id (required)
        :param MessageEndpoint message_endpoint: Message (required)
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MessageEndpoint, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['message_endpoint_id', 'message_endpoint', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace_message_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'message_endpoint_id' is set
        if self.api_client.client_side_validation and ('message_endpoint_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['message_endpoint_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message_endpoint_id` when calling `replace_message_endpoint`")  # noqa: E501
        # verify the required parameter 'message_endpoint' is set
        if self.api_client.client_side_validation and ('message_endpoint' not in local_var_params or  # noqa: E501
                                                        local_var_params['message_endpoint'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message_endpoint` when calling `replace_message_endpoint`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'message_endpoint_id' in local_var_params:
            path_params['message_endpoint_id'] = local_var_params['message_endpoint_id']  # noqa: E501

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'message_endpoint' in local_var_params:
            body_params = local_var_params['message_endpoint']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/messages/{message_endpoint_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MessageEndpoint',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_message_endpoint(self, user_id, message_endpoint, **kwargs):  # noqa: E501
        """Register a messaging endpoint on a user.  # noqa: E501

        Register a messaging endpoint on a user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_message_endpoint(user_id, message_endpoint, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: user_id path (required)
        :param MessageEndpoint message_endpoint: Message (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MessageEndpoint
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_message_endpoint_with_http_info(user_id, message_endpoint, **kwargs)  # noqa: E501

    def update_message_endpoint_with_http_info(self, user_id, message_endpoint, **kwargs):  # noqa: E501
        """Register a messaging endpoint on a user.  # noqa: E501

        Register a messaging endpoint on a user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_message_endpoint_with_http_info(user_id, message_endpoint, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str user_id: user_id path (required)
        :param MessageEndpoint message_endpoint: Message (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MessageEndpoint, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id', 'message_endpoint']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_message_endpoint" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ('user_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['user_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `user_id` when calling `update_message_endpoint`")  # noqa: E501
        # verify the required parameter 'message_endpoint' is set
        if self.api_client.client_side_validation and ('message_endpoint' not in local_var_params or  # noqa: E501
                                                        local_var_params['message_endpoint'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `message_endpoint` when calling `update_message_endpoint`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in local_var_params:
            path_params['user_id'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'message_endpoint' in local_var_params:
            body_params = local_var_params['message_endpoint']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/messages/register/{user_id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MessageEndpoint',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
